(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[405],{8312:function(e,t,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/",function(){return n(4186)}])},6771:function(e,t,n){"use strict";n.d(t,{Z:function(){return _}});var i=n(5893),r=n(7294),s=n(1163),o=n(9008),l=n.n(o),a=n(3946),c=n(8849),d=n(5317),u=n(8298),h=n(2734),p=n(2293),m=n(9520),x=n(155),y=n(6886),f=n(3321),g=n(5861),j=n(7357);function v(e){let{children:t}=e,n=(0,u.Z)({disableHysteresis:!0,threshold:24});return(0,r.cloneElement)(t,{elevation:n?4:0})}var w=function(){let[e,t]=(0,r.useState)(!1);(0,r.useCallback)(()=>{t(!e)},[e]);let n=(0,h.Z)();return(0,i.jsx)(i.Fragment,{children:(0,i.jsx)(v,{children:(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)(p.Z,{color:"transparent",elevation:0,children:(0,i.jsx)(m.Z,{maxWidth:"xl",sx:{padding:0},children:(0,i.jsx)(x.Z,{sx:{minHeight:50,maxHeight:50,padding:0,flex:1,alignItems:"center",justifyContent:"space-between",display:"flex",flexWrap:"nowrap"},children:(0,i.jsx)(y.ZP,{item:!0,children:(0,i.jsx)(f.Z,{href:"https://system-bridge.timmo.dev",target:"_blank",children:(0,i.jsx)(g.Z,{component:"div",variant:"h4",sx:{textTransform:"none",userSelect:"none",color:n.palette.primary.contrastText},children:"System Bridge"})})})})})}),(0,i.jsx)(j.Z,{sx:{height:n.spacing(18)}})]})})})};let Z=!1;var _=function(e){let t=(0,s.useRouter)();return(0,r.useEffect)(()=>{if(t.isReady&&!Z){var e,n,i,r;Z=!0;let s=(null===(e=t.query)||void 0===e?void 0:e.apiKey)||"",o=(null===(n=t.query)||void 0===n?void 0:n.apiPort)||"9170",l=!1;if((null===(i=t.query)||void 0===i?void 0:i.apiKey)||(l=!0,s=window.prompt("Please enter your API key",s)),(null===(r=t.query)||void 0===r?void 0:r.apiPort)||(l=!0,o=window.prompt("Please enter your API port (default: 9170)",o)),l&&s&&o){let e=t.asPath.split("?")[0];t.replace({pathname:e.includes(".html")?e:"".concat(e,".html"),query:{...t.query,apiKey:s,apiPort:o}})}}},[t]),(0,i.jsxs)(i.Fragment,{children:[(0,i.jsxs)(l(),{children:[(0,i.jsx)("title",{children:e.title?"".concat(e.title," - System Bridge"):"System Bridge"}),(0,i.jsx)("link",{rel:"canonical",href:e.url}),(0,i.jsx)("meta",{name:"description",content:e.description?"".concat(e.description):e.title?"".concat(e.title," - System Bridge"):"System Bridge"}),(0,i.jsx)("meta",{name:"keywords",content:e.keywords?"".concat(e.keywords):"system-bridge, system, bridge, typescript"})]}),!e.noHeader&&(0,i.jsx)(w,{}),e.closeButton&&(0,i.jsx)(a.Z,{size:"small",sx:{position:"absolute",top:4,right:4,zIndex:1e3},onClick:()=>{window.location.href="http://close.window"},children:(0,i.jsx)(c.Icon,{id:"close",path:d.r5M,size:1})}),e.children]})}},4186:function(e,t,n){"use strict";n.r(t);var i=n(5893);n(7294);var r=n(9520),s=n(6771);t.default=function(){return(0,i.jsx)(s.Z,{title:"Placeholder",url:"https://system-bridge.timmo.dev",description:"Frontend for System Bridge",children:(0,i.jsx)(r.Z,{component:"article",maxWidth:"xl",children:(0,i.jsx)(i.Fragment,{})})})}}},function(e){e.O(0,[702,502,774,888,179],function(){return e(e.s=8312)}),_N_E=e.O()}]);