(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[998],{3049:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/app/player/video",function(){return t(540)}])},540:function(e,n,t){"use strict";t.r(n);var r=t(5893);t(7294);var i=t(7467),o=t(6771),u=t(2651);n.default=function(){return(0,r.jsx)(o.Z,{title:"Video Player",url:"https://system-bridge.timmo.dev",description:"Frontend for System Bridge",closeButton:!0,noHeader:!0,children:(0,r.jsx)(i.I0,{children:(0,r.jsx)(u.Z,{playerType:"video"})})})}}},function(e){e.O(0,[702,662,885,502,792,674,548,774,888,179],function(){return e(e.s=3049)}),_N_E=e.O()}]);