self.__BUILD_MANIFEST=function(s,a,c,e,t,p,i,d,n,f,b,u){return{__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":[s,a,"static/chunks/pages/index-01635a6bca2dae2f.js"],"/_error":["static/chunks/pages/_error-8353112a01355ec2.js"],"/app/bridges/openon":[s,a,c,e,p,i,d,"static/chunks/pages/app/bridges/openon-016447572216781a.js"],"/app/bridges/setup":[s,a,c,e,p,i,n,"static/chunks/pages/app/bridges/setup-a2f292014913eafc.js"],"/app/data":[s,t,a,e,"static/chunks/716-e5b3f3f48b0832c0.js","static/chunks/pages/app/data-181fed26dc0cbd15.js"],"/app/notification":[s,a,i,"static/chunks/pages/app/notification-a9792ef5314edca4.js"],"/app/player/audio":[s,t,f,a,c,b,u,"static/chunks/pages/app/player/audio-fe3c8670c5c5a2c3.js"],"/app/player/video":[s,t,f,a,c,b,u,"static/chunks/pages/app/player/video-d50c314edee3406d.js"],"/app/settings":[s,t,a,c,e,p,d,n,"static/chunks/826-977d39acd803d41c.js","static/chunks/pages/app/settings-c02993cbc6308c7e.js"],sortedPages:["/","/_app","/_error","/app/bridges/openon","/app/bridges/setup","/app/data","/app/notification","/app/player/audio","/app/player/video","/app/settings"]}}("static/chunks/b2e984c5-f44d94ec783f59d4.js","static/chunks/502-c0e5b6eb99c886c3.js","static/chunks/792-ede710d89c381aa9.js","static/chunks/316-a19dd0a9e80f3ec0.js","static/chunks/29107295-308b8b2c345f6613.js","static/chunks/699-6ba4c7428e32f47b.js","static/chunks/945-cbdfccf2082dd35a.js","static/chunks/447-49ca150c9e928819.js","static/chunks/767-a14097fc84109342.js","static/chunks/75fc9c18-36f994258e23e278.js","static/chunks/674-f722c9db384e6066.js","static/chunks/548-90a1d1f9821b6e49.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();